/**
 * Internal dependencies
 */
import { AdminContext } from 'admin';
import { toNumber } from 'admin/common/helper';

/**
 * WordPress dependencies
 */
import { __ } from '@wordpress/i18n';
import { useContext, useState } from '@wordpress/element';
import { info } from '@wordpress/icons';

import {
	PanelRow,
	RangeControl,
	Button,
	Modal
} from '@wordpress/components';

const LineDecorationsWidth = () => {
	const { editorOptions, setEditorOptions } = useContext( AdminContext );
	const [ isModalOpen, setIsModalOpen ] = useState( false );

	const handleChange = ( value ) => {
		setEditorOptions({
			...editorOptions,
			lineDecorationsWidth: value ? toNumber( value, 0, 30 ) : 0
		});
	};

	return (
		<PanelRow>
			<RangeControl
				label={ __( 'Folding area width (px)', 'custom-html-block-extension' ) }
				value={ editorOptions.lineDecorationsWidth }
				min="0"
				max="30"
				allowReset
				onChange={ handleChange }
			/>
			{ isModalOpen && (
				<Modal
					title={ __( 'Folding area width (px)', 'custom-html-block-extension' ) }
					className="chbe-modal"
					onRequestClose={ () => setIsModalOpen( false ) }
				>
					<img
						src={ chbeObj.assetPath + '/assets/images/admin/editor-config/editor-options/line-decorations-width.gif' }
						alt={ __( 'Folding area width (px)', 'custom-html-block-extension' ) }
					/>
				</Modal>
			)}
			<Button
				className="chbe-help"
				icon={ info }
				label={ __( 'Information', 'custom-html-block-extension' ) }
				onClick={ () => setIsModalOpen( true ) }
			></Button>
		</PanelRow>
	);
};

export default LineDecorationsWidth;
